# De dados à decisão – o fluxo de dados em biodiversidade
## 12 de Junho de 2017

O dado sobre biodiversidade cumpre um longo trajeto, com várias etapas intermediárias,  até chegar ao seu consumidor final e participar do processo de tomada de decisão. Assim como um produto de varejo qualquer, como uma blusa por exemplo, que é composta de tecido, linha e botões agregados de forma precisa e lógica, o dado sobre a biodiversidade é como o botão, ou a linha, ou mesmo o tecido. Na mão de “alfaiates” habilidosos estes elementos tomam forma e propósito.

![](http://dalcinweb.s3-website-us-east-1.amazonaws.com/github/BiodivDadosMeta/dadosDecisao1.jpg)

Uma vez formada a imagem ilustrativa com o exemplo da blusa, fica fácil imaginar o produto final como a agregação de diferentes elementos – ou recursos de informação – cuja produção cumpre uma série de etapas ou trechos até chegar a sua forma final, que é atender um propósito específico do seu consumidor.  Assim, o que pretendo discutir aqui são os trechos percorridos pelo dado, da sua coleta até se transformar em um produto final, pronto para ser “consumido” em um processo de tomada de decisão.

Não pretendo aqui me deter nas etapas deste fluxo já consolidadas ou bem familiares aos leitores. Porém, pretendo me deter um pouco mais detalhadamente no que chamo aqui de “a última milha”.

O termo “last mile“, ou última milha, é utilizado em telecomunicações e no comércio para caracterizar a última etapa da entrega do serviço ou produto ao consumidor 1, 2. Gostaria então de me apropriar deste termo, e usar desta analogia, para caracterizar e discutir aqui a última etapa da entrega da informação sobre biodiversidade para o consumidor final, também caracterizado aqui como o tomador de decisão.

## O início da viagem

O primeiro trecho podemos chamar de “coleta“, que corresponde a observação do fato no mundo real e sua transcrição, de forma automatizada, como em “camera traps” ou sensoriamento remoto por exemplo; ou manual, como em cadernetas de campo. É o registro do fato biológico.

![](http://dalcinweb.s3-website-us-east-1.amazonaws.com/github/BiodivDadosMeta/dadosDecisao2.jpg)

O segundo trecho podemos chamar de “sistematização“, onde este dado primário de ocorrência, taxonômico, ambiental ou socioeconômico, é sistematizado de forma estruturada, geralmente em uma planilha de dados, ou  através de um sistema informatizado, em um banco de dados. Chegamos então ao dado primário sobre biodiversidade3.

![](http://dalcinweb.s3-website-us-east-1.amazonaws.com/github/BiodivDadosMeta/dadosDecisao3.jpg)

Podemos chamar de “__tratamento e qualificação__” um terceiro trecho, onde o dados primário recebem, tem refinado ou validado, seus contextos espaciais, taxonômicos, temáticos e temporais. É, por exemplo, onde a amostra recebe ou tem validada a sua identificação taxonômica. Dados de incerteza e precisão espacial também podem ser associados neste trecho.

![](http://dalcinweb.s3-website-us-east-1.amazonaws.com/github/BiodivDadosMeta/dadosDecisao4.jpg)

Neste ponto chegamos aos primeiros produtos intermediários, primeira parada obrigatória para cumprir a “última milha”.

A partir destes produtos intermediários, processos de síntese e análise transformam estes produtos de intermediários em produtos finais de informação. Entretanto, apesar de “finais”, ainda necessitam cumprir mais um trecho – a última milha – para chegar nos tomadores de decisão: a “__customização e contextualização__“.

Neste ponto, antes de procurar destrinchar as características desta ultima etapa, vale a pena resumir e exemplificar o fluxo completo do dado de biodiversidade até que possa chegar na tomada de decisão:

![](http://dalcinweb.s3-website-us-east-1.amazonaws.com/github/BiodivDadosMeta/dadosDecisao5.jpg)

Podemos exemplificar este fluxo com um exemplo muito simples:

![](http://dalcinweb.s3-website-us-east-1.amazonaws.com/github/BiodivDadosMeta/dadosDecisao6.jpg)

Chegamos no ponto onde o último trecho da entrega da informação ao consumidor se caracteriza como resultado da etapa de “customização e contextualização”, onde percebemos a importância de indicadores e índices, que criam um contexto;  associados a uma visualização direta, limpa e elegante. Customizada para o consumidor.

## Indicadores e Índices

Um índice é o valor agregado final de todo um procedimento de cálculo onde se utilizam, inclusive, indicadores como variáveis que o compõem. Pode-se dizer também que um índice é simplesmente um indicador de alta categoria 4.

Uma lista considerável de indicadores e índices relacionados com as metas de AICHI pode ser encontrada neste “Report Of The Ad Hoc Technical Expert Group On Indicators For The Strategic Plan For Biodiversity 2011-2020“. O que não faltam são índices!

Os indicadores e índices são a materialização da etapa final de “__customização e contextualização__“, conferindo ao dado uma __forma__ para que atinja seu __propósito__: o de informar.

No caso específico do exemplo acima, o Red List Index, um indicador definido para a Meta 12 de Aichi,  informa “as tendências do risco geral de extinção (“estado de conservação”) de conjuntos de espécies, como indicador das tendências no estado da biodiversidade“ 5.

Creio que fica claro que nesta caminhada até compor um índice, o dado vai agregando valor em seu processo de transformação. Como no exemplo da blusa, o dado no campo é como o a fibra do algodão ainda dentro do capulho, que precisa ser coletado e em seus processos de beneficiamento vai agregando valor e se prestando à variados propósitos intermediários, como uma linha e um tecido. Da mesma forma que alguns metros de tecido e um carretel de linha não atingem o propósito de vestir e aquecer, produtos intermediários e finais de informação não estão ainda adequados para tomada de decisão, pois lhe faltam o contexto e a customização.

Comentários são sempre bem vindos!

## Referências

[1] Cambridge Dictionary. Meaning of “the last mile” in the English Dictionary. Disponívem em http://dictionary.cambridge.org/dictionary/english/last-mile. Acessado em 29/04/2017

[2] Wikipedia. Last mile. Disponível em https://en.wikipedia.org/wiki/Last_mile. Acessado em 29/04/2017

[3] Soberón, J., & Peterson, T. (2004). Biodiversity informatics: managing and applying primary biodiversity data. Philosophical Transactions of the Royal Society of London B: Biological Sciences, 359(1444), 689-698.

[4] Agostinho, F., Ortega, E., & Romeiro, A. (2007). Índices versus indicadores: precisões conceituais na discussão da sustentabilidade de países. Ambiente & sociedade, 10(2), 137-148.

[5] Bubb, P.J., Butchart, S.H.M., Collen, B., Dublin, H., Kapos, V., Pollock, C., Stuart, S. N., Vié, J-C. (2009). IUCN Red List Index – Guidance for National and Regional Use. Gland, Switzerland: IUCN.

## Leitura Adicional

Biodiversity Indicators Partnership. (2011) Guidance for national biodiversity indicator development and use. UNEP World Conservation Monitoring Centre, Cambridge, UK. 40pp. Version 1.4. March 2011.

Bowles-Newark, N.J., Despot-Belmonte, K., Misrachi, M. and Chenery, A. (2015). Using global biodiversity indicators and underlying data to support NBSAP development and national reporting: Roadmap to support NBSAP practitioners. UNEP- WCMC; Cambridge.

Stephenson, P. J., Bowles-Newark, N., Regan, E., Stanwell-Smith, D., Diagana, M., Höft, R., … & Banki, O. (2016). Unblocking the flow of biodiversity data for decision-making in Africa. Biological Conservation.

Stephenson, P. J., Burgess, N. D., Jungmann, L., Loh, J., O’Connor, S., Oldfield, T., … & Shapiro, A. (2015). Overcoming the challenges to conservation monitoring: integrating data from in-situ reporting and global data sets to measure impact and performance. Biodiversity, 16(2-3), 68-85.

